# mlflow-algorithmia Change Log

## [Unreleased]

## [0.1.2]

- Fix mlflow predict command serialization

## [0.1.1]

- Pin to newer dependencies of mlflow and algorithmia
- Output new version of the model

## [0.1.0]

- Initial release
